@@ -1,5 +1,5 @@
 /////////////////////////////////////////////////////////////////////////////
-// Copyright (c) 2009-2011 Alan Wright. All rights reserved.
+// Copyright (c) 2009-2014 Alan Wright. All rights reserved.
 // Distributable under the terms of either the Apache License (Version 2.0)
 // or the GNU Lesser General Public License.
 /////////////////////////////////////////////////////////////////////////////
@@ -7,13 +7,12 @@
 #include "LuceneInc.h"
 #include "IndexDeletionPolicy.h"
 
-namespace Lucene
-{
-    IndexDeletionPolicy::IndexDeletionPolicy()
-    {
-    }
+namespace Lucene {
+
+IndexDeletionPolicy::IndexDeletionPolicy() {
+}
+
+IndexDeletionPolicy::~IndexDeletionPolicy() {
+}
 
-    IndexDeletionPolicy::~IndexDeletionPolicy()
-    {
-    }
 }
