@@ -17,11 +17,16 @@ LuceneTestFixture::LuceneTestFixture() {
 }
 
 LuceneTestFixture::~LuceneTestFixture() {
+    // Moved out to a separate function since GTEST_FAIL cannot be used in destructors
+    destructorBody();
+}
+
+void LuceneTestFixture::destructorBody() {
     DateTools::setDateOrder(DateTools::DATEORDER_LOCALE);
     if (ConcurrentMergeScheduler::anyUnhandledExceptions()) {
         // Clear the failure so that we don't just keep failing subsequent test cases
         ConcurrentMergeScheduler::clearUnhandledExceptions();
-        FAIL() << "ConcurrentMergeScheduler hit unhandled exceptions";
+        boost::throw_exception(RuntimeException(L"ConcurrentMergeScheduler hit unhandled exceptions"));
     }
 }
 
